# from typing import Literal
from datetime import timedelta
from Adafruit_BBIO.GPIO import HIGH, LOW, BOTH, FALLING
from typing_extensions import Literal


# MISCELLANEOUS CONSTS
RELAY = "relay"
ON = "ON"
OFF = "OFF"
STATE = "state"
ENABLED = "enabled"
OUTPUT = "output"
PIN = "pin"
ID = "id"
KIND = "kind"
GPIO = "gpio"
ACTIONS = "actions"
ACTION = "action"
OUTPUT = "output"
SWITCH = "switch"
CONFIG_PIN = "/usr/bin/config-pin"
UPDATE_INTERVAL = "update_interval"
ADC = "adc"
IP = "ip"
MASK = "mask"
MAC = "mac"
NONE="none"

# TIMINGS FOR BUTTONS
DEBOUNCE_DURATION = timedelta(seconds=0.2)
LONG_PRESS_DURATION = timedelta(seconds=0.7)
DELAY_DURATION = 0.1
SECOND_DELAY_DURATION = 0.3

# HA CONSTS
HOMEASSISTANT = "homeassistant"
HA_DISCOVERY = "ha_discovery"
HA_TYPE = "ha_type"
SHOW_HA = "show_in_ha"

# OLED CONST
OLED = "oled"
FONTS = "fonts"
OLED_PIN = "P9_41"
GIGABYTE = 1073741824
MEGABYTE = 1048576
WIDTH = 128
UPTIME = "uptime"
NETWORK = "network"
CPU = "cpu"
DISK = "disk"
MEMORY = "memory"
SWAP = "swap"
WHITE = "white"

# INPUT CONST
INPUT = "input"
SINGLE = "single"
DOUBLE = "double"
LONG = "long"
PRESSED = "pressed"
RELEASED = "released"


# MQTT CONST
PAHO = "paho.mqtt.client"
MQTT = "mqtt"
HOST = "host"
USERNAME = "username"
PASSWORD = "password"
ONLINE = "online"
TOPIC_PREFIX = "topic_prefix"

# I2C and MCP CONST
ADDRESS = "address"
MCP23017 = "mcp23017"
MCP = "mcp"
MCP_ID = "mcp_id"
INIT_SLEEP = "init_sleep"

# SENSOR CONST
TEMPERATURE = "temperature"
SENSOR = "sensor"
BINARY_SENSOR = "binary_sensor"
LM75 = "lm75"
INPUT_SENSOR = "inputsensor"

# TYPING
ClickTypes = Literal[SINGLE, DOUBLE, LONG, PRESSED, RELEASED]
OledDataTypes = Literal[UPTIME, NETWORK, CPU, DISK, MEMORY, SWAP, OUTPUT]
Gpio_States = Literal[HIGH, LOW]
Gpio_Edges = Literal[BOTH, FALLING]
InputTypes = Literal[INPUT, INPUT_SENSOR]



"""Sensor module."""
from boneio.sensor.lm75 import LM75Sensor
from boneio.sensor.gpio import GpioInputSensor
from boneio.sensor.adc import initialize_adc, GpioADCSensor

__all__ = ["LM75Sensor", "GpioInputSensor", "initialize_adc", "GpioADCSensor"]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()


with open("boneio/version.py") as f:
    exec(f.read())

setup(
    name="boneio",
    version=__version__,  # type: ignore # noqa: F821,
    description="Python Helper for BoneIO",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/maciejk1984/boneIO",
    download_url="https://github.com/maciejk1984/boneIO/archive/{}.zip".format(
        __version__  # type: ignore # noqa: F821
    ),
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    license="GNU General Public License v3.0",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    install_requires=[
        "Adafruit-BBIO==1.2.0",
        "Adafruit-Blinka==6.15.0",
        "adafruit-circuitpython-mcp230xx==2.5.1",
        "adafruit-circuitpython-pct2075==1.1.11",
        "Adafruit-PlatformDetect==3.17.2",
        "Adafruit-PureIO==1.1.9",
        "asyncio-mqtt==0.10.0",
        "Cerberus==1.3.4",
        "click==8.0.3",
        "colorlog==6.5.0",
        "gpio==0.3.0",
        "luma.core==2.3.1",
        "luma.oled==3.8.1",
        "numpy==1.21.4",
        "paho-mqtt==1.6.1",
        "psutil==5.8.0",
        "pyaml==21.10.1",
        "typing-extensions==3.10.0.2",
    ],
    entry_points={"console_scripts": ["boneio=boneio.bonecli:cli"]},
)
